==> comedilib_0.10.1.orig.tar.gz: comedilib-0.10.1/lib/calib_yacc.h <==
/* A Bison parser, made by GNU Bison 2.4.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2009, 2010 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_DRIVER_NAME = 258,
     T_BOARD_NAME = 259,
     T_CALIBRATIONS = 260,
     T_SUBDEVICE = 261,
     T_CHANNELS = 262,
     T_RANGES = 263,
     T_AREFS = 264,
     T_CALDACS = 265,
     T_CHANNEL = 266,
     T_VALUE = 267,
     T_NUMBER = 268,
     T_STRING = 269,
     T_COEFFICIENTS = 270,
     T_EXPANSION_ORIGIN = 271,
     T_SOFTCAL_TO_PHYS = 272,
     T_SOFTCAL_FROM_PHYS = 273,
     T_ASSIGN = 274,
     T_FLOAT = 275
   };
#endif
/* Tokens.  */
#define T_DRIVER_NAME 258
#define T_BOARD_NAME 259
#define T_CALIBRATIONS 260
#define T_SUBDEVICE 261
#define T_CHANNELS 262
#define T_RANGES 263
#define T_AREFS 264
#define T_CALDACS 265
#define T_CHANNEL 266
#define T_VALUE 267
#define T_NUMBER 268
#define T_STRING 269
#define T_COEFFICIENTS 270
#define T_EXPANSION_ORIGIN 271
#define T_SOFTCAL_TO_PHYS 272
#define T_SOFTCAL_FROM_PHYS 273
#define T_ASSIGN 274
#define T_FLOAT 275




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1685 of yacc.c  */
#line 355 "../../comedilib/lib/calib_yacc.y"

	int  ival;
	double dval;
	char *sval;



/* Line 1685 of yacc.c  */
#line 99 "../../comedilib/lib/calib_yacc.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

==> comedilib_0.10.2.orig.tar.gz: comedilib-0.10.2/lib/calib_yacc.h <==
/* A Bison parser, made by GNU Bison 2.7.12-4996.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED
# define YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED
/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int calib_yydebug;
#endif

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_DRIVER_NAME = 258,
     T_BOARD_NAME = 259,
     T_CALIBRATIONS = 260,
     T_SUBDEVICE = 261,
     T_CHANNELS = 262,
     T_RANGES = 263,
     T_AREFS = 264,
     T_CALDACS = 265,
     T_CHANNEL = 266,
     T_VALUE = 267,
     T_NUMBER = 268,
     T_STRING = 269,
     T_COEFFICIENTS = 270,
     T_EXPANSION_ORIGIN = 271,
     T_SOFTCAL_TO_PHYS = 272,
     T_SOFTCAL_FROM_PHYS = 273,
     T_ASSIGN = 274,
     T_FLOAT = 275
   };
#endif
/* Tokens.  */
#define T_DRIVER_NAME 258
#define T_BOARD_NAME 259
#define T_CALIBRATIONS 260
#define T_SUBDEVICE 261
#define T_CHANNELS 262
#define T_RANGES 263
#define T_AREFS 264
#define T_CALDACS 265
#define T_CHANNEL 266
#define T_VALUE 267
#define T_NUMBER 268
#define T_STRING 269
#define T_COEFFICIENTS 270
#define T_EXPANSION_ORIGIN 271
#define T_SOFTCAL_TO_PHYS 272
#define T_SOFTCAL_FROM_PHYS 273
#define T_ASSIGN 274
#define T_FLOAT 275



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{
/* Line 2053 of yacc.c  */
#line 347 "../../comedilib/lib/calib_yacc.y"

	int  ival;
	double dval;
	char *sval;


/* Line 2053 of yacc.c  */
#line 104 "../../comedilib/lib/calib_yacc.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif


#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int calib_yyparse (void *YYPARSE_PARAM);
#else
int calib_yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int calib_yyparse (calib_yyparse_private_t *parse_arg);
#else
int calib_yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */

#endif /* !YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED  */
